#
# spec file for package perl-Module-Implementation
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Module-Implementation
Name:           perl-Module-Implementation
Version:        0.90.0
Release:        1.1
# 0.09 -> normalize -> 0.90.0
%define cpan_version 0.09
License:        Artistic-2.0
Summary:        Loads one of several alternate underlying implementations for a module
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DR/DROLSKY/%{cpan_name}-%{cpan_version}.tar.gz
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Runtime) >= 0.12
BuildRequires:  perl(Test::Fatal) >= 0.6
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Try::Tiny)
Requires:       perl(Module::Runtime) >= 0.12
Requires:       perl(Try::Tiny)
Provides:       perl(Module::Implementation) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module abstracts out the process of choosing one of several underlying
implementations for a module. This can be used to provide XS and pure Perl
implementations of a module, or it could be used to load an implementation
for a given OS or any other case of needing to provide multiple
implementations.

This module is only useful when you know all the implementations ahead of
time. If you want to load arbitrary implementations then you probably want
something like a plugin system, not this module.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md
%license LICENSE

%changelog
* Tue May 20 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.09
  see /usr/share/doc/packages/perl-Module-Implementation/Changes
  0.09     2014-08-24
  - Backed out the Sub::Name change in 0.08. It was pointed out to me by Graham
    Knop that adding an XS dependency for a module that's often used to pick
    between XS and non-XS implementations doesn't work so well.
  0.08     2014-08-24
  - Subroutines copied from an implementation package into the loading package
    are now renamed using Sub::Name. This causes them to be considered part of
    the loading package, which is important for things like
    namespace::autoclean. Reported by Karen Etheridge. RT #98097.
* Thu Jun 26 2014 lchiquitto@suse.com
- really remove old old_test_more.patch from package sources
* Fri Jul 26 2013 coolo@suse.com
- updated to 0.07
  - Require Test::Fatal 0.006+ to avoid test failures. Reported by Salve
    Nilsen. RT #76809.
- remove old old_test_more.patch
* Sun Jun  9 2013 coolo@suse.com
- updated to 0.06
  - Require Module::Runtime 0.012 which has a number of useful bug fixes.
* Wed Feb 29 2012 ro@suse.de
- fix build with old Test::More for sle11
* Fri Feb 10 2012 vcizek@suse.com
- update to 0.05
  - Make Test::Taint an optional dependency. This module requires XS, and
    requiring a compiler for Module::Implementation defeats its
    purpose. Reported by Peter Rabbitson. RT #74817.
  - This module no longer installs an _implementation() subroutine in
    callers. Instead, you can call
    Module::Implementation::implementation_for($package) to get the
    implementation used for a given package.
* Wed Feb  8 2012 vcizek@suse.com
- version 0.03 (initial package )
